yakumo.keystone.v3.region.Manager

Package yakumo :: Package keystone :: Package v3 :: Module region :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for regions on Identity V3 API

Nested Classes | [hide private]
| resource_class resource class for regions on Identity V3 API

Instance Methods | [hide private]
yakumo.keystone.v3.region.Resource |
create(self, id=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, parent=`'``__UNDEF__``'`) Register a region | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``identity``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``region``'``
| _json_resources_key = ``'``regions``'``
| _update_method = ``'``patch``'``
| _url_resource_path = ``'``/regions``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, id=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, parent=`'``__UNDEF__``'`) | source code
Register a region Parameters: `id` (str) - ID `description` (str) - Description `parent` (yakumo.keystone.v3.region.Resource) - Parent region Returns: yakumo.keystone.v3.region.Resource Created region Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('description', 'description', mapper.Noop
      ), ('parent', 'parent_region_id', mapper.Resource('keystone.region')),
      ]